function [itest,xtest,hptest,RPMtest]=rpmline(i,x,hp,RPM)
% function [itest,xtest,hptest,RPMtest]=rpmline(i,x,hp,RPM)
% i=1, 2, 3, 4, or 5
% itest is the array giving the element numbers of the ith rpm line in x and hp.
% xtest is the x coordinate of the ith rpm line.
% hptest is the hp valus for the ith rpm line.
% RPMtest is a scalar rpm of r the ith line.
itest=i:5:length(x);
xtest=x(itest);
hptest=hp(itest);
RPMtest=RPM(i);
